@@ -19,8 +19,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
-#ifndef _SAMBA_LOG_MODE_H_
-#define _SAMBA_LOG_MODE_H_
+#ifndef SAMBA_LOG_MODE_H
+#define SAMBA_LOG_MODE_H
 
 /**
  * Samba Log Mode Identifier
@@ -52,9 +52,9 @@ public:
 
     ~SambaLogMode();
 
-    Analyzer *createAnalyzer(const QVariant &options = QVariant()) Q_DECL_OVERRIDE;
+    Analyzer *createAnalyzer(const QVariant &options = QVariant()) override;
 
-    QList<LogFile> createLogFiles() Q_DECL_OVERRIDE;
+    QList<LogFile> createLogFiles() override;
 };
 
-#endif // _SAMBA_LOG_MODE_H_
+#endif // _SAMBA_LOG_MODE_H
